@import '~@synerty/peek-theme/scss/_mixins.web';
@import '~@synerty/peek-theme/scss/_variables.web';

.peek-page-contents {
  overflow-y: scroll;
  position: fixed;
  top: $title_bar_height;
  bottom: $mobile_footer_bar_height;
  left: 0;
  right: 0;
}