@import '~@synerty/peek-theme/scss/_mixins.ns';
@import '~@synerty/peek-theme/scss/_variables.ns';

.peek-footer {
    /* Style */
    background-color: $white;

    /* Layout */

    .footer-bar-btn {
        /* Style */
        color: $white;
        cursor: pointer;
        border: 0;
        font-size: $general_font_size_1;
        border-radius: 0;
        background-color: $brand;
        border-right: $general_border solid $brand_dark;
        border-left: 0;

        /* Layout */
        padding: $general_padding_2;
        margin-right: 0;
    }

        .footer-bar-btn-disabled {
            cursor: not-allowed;
            box-shadow: none;
            background-color: $general_button_background_disabled;
            color: $font_colour_disabled;
        }

    .footer-bar-text {
        /* Style */
        font-size: $general_font_size_1;
        text-align: center;
        color: $black;

        /* Layout */
        vertical-align: center;
        padding-left: $general_padding_1;
        padding-right: $general_padding_1;
    }
}
