@import '~@synerty/peek-theme/scss/_mixins.web';
@import '~@synerty/peek-theme/scss/_variables.web';

.peek-footer {
    /* Style */
    background-color: $white;

    /* Layout */
    position: fixed;
    bottom: 0;
    width: 100%;
    height: $mobile_footer_bar_height;
    display: flex;
    z-index: 1001;
    overflow: hidden;

    .btn-group {
        /* Style */

        /* Layout */
        position: relative;
        float: left;
        border-radius: $general_border_radius;

        .footer-bar-btn {
            /* Style */
            color: $white;
            cursor: pointer;
            border: 0;
            font-size: $general_font_size_2;
            border-radius: 0;
            background-color: $brand;
            border-right: $general_border solid $brand_dark;
            border-left: 0;

            /* Layout */
            height: $mobile_footer_bar_height;
            margin-right: 0;
            display: inline-block;
            position: relative;
            min-width: $title_bar_button_min_width;
            float: left;
        }

        .footer-bar-btn {
            &:last-child {
                border-right: 0;
            }
        }

        .footer-bar-btn-disabled {
            cursor: not-allowed;
            box-shadow: none;
            background-color: $general_button_background_disabled;
            color: $font_colour_disabled;
        }
    }

    .footer-bar-text {
        /* Style */
        font-size: $general_font_size_2;
        text-align: center;
        color: $black;

        /* Layout */
        line-height: $mobile_footer_bar_height;
        margin: auto;
        width: 50%;
    }

}
